Crate vortex_datafusion

Crate vortex_datafusion 

Connectors to enable DataFusion to read Vortex data.

Modules

metrics
Vortex table provider metrics.
v2
An experimental implementation of the Vortex Scan API for DataFusion.

Structs

VortexAccessPlan
Custom Vortex-specific information that can be provided by external indexes or other sources.
VortexFormat
Vortex implementation of a DataFusion FileFormat.
VortexFormatFactory
Minimal factory to create VortexFormat instances.
VortexSource
Execution plan for reading one or more Vortex files, intended to be consumed by DataSourceExec.
VortexTableOptions
Options to configure the VortexFormat.

Traits

ExpressionConvertor
Trait for converting DataFusion expressions to Vortex ones.