Module vortex_datafusion::memory
source · Structs
- A
TableProviderthat exposes an existing Vortex Array to the DataFusion SQL engine. - Optional configurations to pass when loading a VortexMemTable.
TableProvider that exposes an existing Vortex Array to the DataFusion SQL engine.