Struct vortex_datafusion::memory::VortexMemTable
source · pub struct VortexMemTable { /* private fields */ }Expand description
A TableProvider that exposes an existing Vortex Array to the DataFusion SQL engine.
Only arrays that have a top-level struct type can be exposed as a table to DataFusion.
Implementations
sourceimpl VortexMemTable
impl VortexMemTable
sourcepub fn new(array: Array, options: VortexMemTableOptions) -> Self
pub fn new(array: Array, options: VortexMemTableOptions) -> Self
Build a new table provider from an existing struct type array.
Panics
Creation will panic if the provided array is not of DType::Struct type.