Connectors to enable DataFusion to read Vortex data.
Modules
- metrics
- Vortex table provider metrics.
- v2
- An experimental implementation of the Vortex Scan API for DataFusion.
Structs
- Vortex
Access Plan - Custom Vortex-specific information that can be provided by external indexes or other sources.
- Vortex
Format - Vortex implementation of a DataFusion
FileFormat. - Vortex
Format Factory - Minimal factory to create
VortexFormatinstances. - Vortex
Source - Execution plan for reading one or more Vortex files, intended to be consumed by
DataSourceExec. - Vortex
Table Options - Options to configure the
VortexFormat.
Traits
- Expression
Convertor - Trait for converting DataFusion expressions to Vortex ones.