VortexSource

Struct VortexSource 

pub struct VortexSource { /* private fields */ }
Execution plan for reading one or more Vortex files, intended to be consumed by DataSourceExec.

Implementations

Source

impl VortexSource

pub fn new(table_schema: TableSchema, session: VortexSession) -> Self

Creates a new VortexSource with default configuration and a provided VortexSession. Meant to be use with a FileScanConfig to scan a file with the provided schema.

Can be configured using the provided methods.

pub fn with_projection_pushdown(self, enabled: bool) -> Self

Enable or disable expression pushdown into the underlying Vortex scan.

pub fn with_expression_convertor( self, expr_convertor: Arc<dyn ExpressionConvertor>, ) -> Self

Set a ExpressionConvertor to control how Datafusion expression should be converted and pushed down.

pub fn with_vortex_reader_factory( self, vortex_reader_factory: Arc<dyn VortexReaderFactory>, ) -> Self

Set a user-defined factory to create the underlying VortexReadAt

pub fn metrics_registry(&self) -> &Arc<dyn MetricsRegistry>

Returns the MetricsRegistry attached to this source.

pub fn with_file_metadata_cache( self, file_metadata_cache: Arc<dyn FileMetadataCache>, ) -> Self

Override the file metadata cache

pub fn with_scan_concurrency(self, scan_concurrency: usize) -> Self

Set the underlying scan concurrency. This limit is used per Vortex scan operations.

pub fn options(&self) -> &VortexTableOptions

Returns the table options for this source.

pub fn with_options(self, opts: VortexTableOptions) -> Self

Set the table options for this source.