pub struct VortexSource { /* private fields */ }Expand description
Execution plan for reading one or more Vortex files, intended to be consumed by DataSourceExec.
Implementations
Sourceimpl VortexSource
impl VortexSource
Sourcepub fn new(table_schema: TableSchema, session: VortexSession) -> Self
pub fn new(table_schema: TableSchema, session: VortexSession) -> Self
Creates a new VortexSource with default configuration and a provided VortexSession.
Meant to be use with a FileScanConfig to scan a file with the provided schema.
Can be configured using the provided methods.
Sourcepub fn with_projection_pushdown(self, enabled: bool) -> Self
pub fn with_projection_pushdown(self, enabled: bool) -> Self
Enable or disable expression pushdown into the underlying Vortex scan.
Sourcepub fn with_expression_convertor(
self,
expr_convertor: Arc<dyn ExpressionConvertor>,
) -> Self
pub fn with_expression_convertor( self, expr_convertor: Arc<dyn ExpressionConvertor>, ) -> Self
Set a ExpressionConvertor to control how Datafusion expression should be converted and pushed down.
Sourcepub fn with_vortex_reader_factory(
self,
vortex_reader_factory: Arc<dyn VortexReaderFactory>,
) -> Self
pub fn with_vortex_reader_factory( self, vortex_reader_factory: Arc<dyn VortexReaderFactory>, ) -> Self
Set a user-defined factory to create the underlying VortexReadAt
Sourcepub fn metrics_registry(&self) -> &Arc<dyn MetricsRegistry>
pub fn metrics_registry(&self) -> &Arc<dyn MetricsRegistry>
Returns the MetricsRegistry attached to this source.
Sourcepub fn with_file_metadata_cache(
self,
file_metadata_cache: Arc<dyn FileMetadataCache>,
) -> Self
pub fn with_file_metadata_cache( self, file_metadata_cache: Arc<dyn FileMetadataCache>, ) -> Self
Override the file metadata cache
Sourcepub fn with_scan_concurrency(self, scan_concurrency: usize) -> Self
pub fn with_scan_concurrency(self, scan_concurrency: usize) -> Self
Set the underlying scan concurrency. This limit is used per Vortex scan operations.
Sourcepub fn options(&self) -> &VortexTableOptions
pub fn options(&self) -> &VortexTableOptions
Returns the table options for this source.
Sourcepub fn with_options(self, opts: VortexTableOptions) -> Self
pub fn with_options(self, opts: VortexTableOptions) -> Self
Set the table options for this source.