VortexTable

Struct VortexTable 

pub struct VortexTable { /* private fields */ }
A DataFusion TableProvider backed by a Vortex DataSourceRef.

Implementations

Source

impl VortexTable

pub fn new( data_source: DataSourceRef, session: VortexSession, arrow_schema: SchemaRef, ) -> Self

Creates a new VortexTable from a Vortex data source and session.

The Arrow schema will be used to emit the correct column names and types to DataFusion. The Vortex DType of the data source should be compatible with this Arrow schema.